You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/01 08:27:13 UTC

svn commit: r1208981 [9/24] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mail...

Modified: struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/SelectHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/SelectHandler.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/SelectHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/main/java/org/apache/struts2/views/java/simple/SelectHandler.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.views.java.simple;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.struts2.components.ListUIBean;
 import org.apache.struts2.components.OptGroup;
 import org.apache.struts2.util.ContainUtil;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/TokenTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/TokenTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/TokenTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/javatemplates/src/test/java/org/apache/struts2/views/java/simple/TokenTest.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.views.java.simple;
 
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionContext;
 import org.apache.struts2.components.Token;
 import org.apache.struts2.components.UIBean;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/main/java/org/apache/struts2/dispatcher/ChartResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/main/java/org/apache/struts2/dispatcher/ChartResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/main/java/org/apache/struts2/dispatcher/ChartResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/main/java/org/apache/struts2/dispatcher/ChartResult.java Thu Dec  1 07:18:07 2011
@@ -22,9 +22,9 @@
 package org.apache.struts2.dispatcher;
 
 import org.apache.struts2.ServletActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.jfree.chart.ChartUtilities;
 import org.jfree.chart.JFreeChart;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/test/java/org/apache/struts2/dispatcher/ChartResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/test/java/org/apache/struts2/dispatcher/ChartResultTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/test/java/org/apache/struts2/dispatcher/ChartResultTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jfreechart/src/test/java/org/apache/struts2/dispatcher/ChartResultTest.java Thu Dec  1 07:18:07 2011
@@ -25,10 +25,10 @@ import org.apache.struts2.ServletActionC
 import org.apache.struts2.StrutsTestCase;
 import org.easymock.EasyMock;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.jfree.chart.ChartFactory;
 import org.jfree.chart.JFreeChart;
 import org.jfree.data.general.DefaultPieDataset;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesInterceptor.java Thu Dec  1 07:18:07 2011
@@ -23,9 +23,9 @@ package org.apache.struts2.jsf;
 
 import javax.faces.context.FacesContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.Interceptor;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.Interceptor;
 
 /**
  * Translates JSF phases into individual interceptors, and adapts their expected

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesResult.java Thu Dec  1 07:18:07 2011
@@ -27,8 +27,8 @@ import javax.faces.context.FacesContext;
 
 import org.apache.struts2.dispatcher.StrutsResultSupport;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
 
 /**
  * Executes the JSF render phase

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSetupInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSetupInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSetupInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSetupInterceptor.java Thu Dec  1 07:18:07 2011
@@ -46,11 +46,11 @@ import org.apache.struts2.ServletActionC
 import org.apache.struts2.StrutsException;
 import org.apache.struts2.util.ClassLoaderUtils;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.interceptor.Interceptor;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.interceptor.Interceptor;
 
 /**
  * * Initializes the JSF context for this request.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSupport.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSupport.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/FacesSupport.java Thu Dec  1 07:18:07 2011
@@ -27,9 +27,9 @@ import javax.faces.event.PhaseId;
 import javax.faces.event.PhaseListener;
 import javax.faces.lifecycle.Lifecycle;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Provides common lifecycle phase methods needed by interceptors and results.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsNavigationHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsNavigationHandler.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsNavigationHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsNavigationHandler.java Thu Dec  1 07:18:07 2011
@@ -26,9 +26,9 @@ import java.util.Map;
 import javax.faces.application.NavigationHandler;
 import javax.faces.context.FacesContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
 
 /**
  * Overrides the JFS navigation by delegating the result to handling by the core

Modified: struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsVariableResolver.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsVariableResolver.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsVariableResolver.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/jsf/src/main/java/org/apache/struts2/jsf/StrutsVariableResolver.java Thu Dec  1 07:18:07 2011
@@ -25,8 +25,7 @@ import javax.faces.context.FacesContext;
 import javax.faces.el.EvaluationException;
 import javax.faces.el.VariableResolver;
 
-import com.opensymphony.xwork2.ognl.OgnlValueStack;
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionContext;
 
 /**
  * Will return a reference to the current action if the action name matches the

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONCleaner.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONCleaner.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONCleaner.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONCleaner.java Thu Dec  1 07:18:07 2011
@@ -28,12 +28,11 @@ import java.util.TreeMap;
 import java.util.HashMap;
 
 import java.util.regex.Pattern;
-import java.util.regex.Matcher;
 
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.WildcardUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.WildcardUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <p>Isolate the process of cleaning JSON data from the Interceptor class

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONInterceptor.java Thu Dec  1 07:18:07 2011
@@ -25,7 +25,6 @@ import java.lang.reflect.InvocationTarge
 import java.lang.reflect.Method;
 import java.lang.reflect.Type;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -42,14 +41,14 @@ import org.apache.struts2.json.rpc.RPCEr
 import org.apache.struts2.json.rpc.RPCErrorCode;
 import org.apache.struts2.json.rpc.RPCResponse;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.WildcardUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.WildcardUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Populates an action from a JSON string

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONPopulator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONPopulator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONPopulator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONPopulator.java Thu Dec  1 07:18:07 2011
@@ -48,8 +48,8 @@ import java.util.Set;
 
 import org.apache.struts2.json.annotations.JSON;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Isolate the process of populating JSON objects from the Interceptor class

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONResult.java Thu Dec  1 07:18:07 2011
@@ -20,14 +20,14 @@
  */
 package org.apache.struts2.json;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.WildcardUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.WildcardUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.StrutsConstants;
 import org.apache.struts2.StrutsStatics;
 import org.apache.struts2.json.smd.SMDGenerator;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONUtil.java Thu Dec  1 07:18:07 2011
@@ -20,10 +20,10 @@
  */
 package org.apache.struts2.json;
 
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.WildcardUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.WildcardUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.json.annotations.SMDMethod;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONValidationInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONValidationInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONValidationInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONValidationInterceptor.java Thu Dec  1 07:18:07 2011
@@ -21,13 +21,13 @@
 
 package org.apache.struts2.json;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ModelDriven;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.interceptor.MethodFilterInterceptor;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ModelDriven;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.struts2.ServletActionContext;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONWriter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONWriter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONWriter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/JSONWriter.java Thu Dec  1 07:18:07 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2.json;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.json.annotations.JSON;
 import org.apache.struts2.json.annotations.JSONFieldBridge;
 import org.apache.struts2.json.annotations.JSONParameter;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/rpc/RPCError.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/rpc/RPCError.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/rpc/RPCError.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/rpc/RPCError.java Thu Dec  1 07:18:07 2011
@@ -23,8 +23,8 @@ package org.apache.struts2.json.rpc;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /*
  * Used to serialize RPC Errors

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/smd/SMDGenerator.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/smd/SMDGenerator.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/smd/SMDGenerator.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/main/java/org/apache/struts2/json/smd/SMDGenerator.java Thu Dec  1 07:18:07 2011
@@ -1,9 +1,9 @@
 package org.apache.struts2.json.smd;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.StrutsStatics;
 import org.apache.struts2.json.JSONUtil;
 import org.apache.struts2.json.annotations.SMD;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONInterceptorTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONInterceptorTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONInterceptorTest.java Thu Dec  1 07:18:07 2011
@@ -30,9 +30,9 @@ import org.springframework.mock.web.Mock
 import org.springframework.mock.web.MockHttpServletResponse;
 import org.springframework.mock.web.MockServletContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.mock.MockActionInvocation;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.mock.MockActionInvocation;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 public class JSONInterceptorTest extends StrutsTestCase {
     private MockActionInvocationEx invocation;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONResultTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONResultTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONResultTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONResultTest.java Thu Dec  1 07:18:07 2011
@@ -42,9 +42,9 @@ import org.springframework.mock.web.Mock
 import org.springframework.mock.web.MockHttpServletResponse;
 import org.springframework.mock.web.MockServletContext;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.mock.MockActionInvocation;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.mock.MockActionInvocation;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * JSONResultTest

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONValidationInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONValidationInterceptorTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONValidationInterceptorTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/JSONValidationInterceptorTest.java Thu Dec  1 07:18:07 2011
@@ -21,16 +21,16 @@
 
 package org.apache.struts2.json;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionSupport;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.mock.MockActionInvocation;
-import com.opensymphony.xwork2.mock.MockActionProxy;
-import com.opensymphony.xwork2.validator.annotations.EmailValidator;
-import com.opensymphony.xwork2.validator.annotations.IntRangeFieldValidator;
-import com.opensymphony.xwork2.validator.annotations.StringLengthFieldValidator;
-import com.opensymphony.xwork2.validator.annotations.Validation;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.mock.MockActionInvocation;
+import org.apache.struts2.xwork2.mock.MockActionProxy;
+import org.apache.struts2.xwork2.validator.annotations.EmailValidator;
+import org.apache.struts2.xwork2.validator.annotations.IntRangeFieldValidator;
+import org.apache.struts2.xwork2.validator.annotations.StringLengthFieldValidator;
+import org.apache.struts2.xwork2.validator.annotations.Validation;
 import org.apache.struts2.StrutsStatics;
 import org.apache.struts2.StrutsTestCase;
 import org.apache.struts2.interceptor.validation.AnnotationValidationInterceptor;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/TestAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/TestAction.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/TestAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/json/src/test/java/org/apache/struts2/json/TestAction.java Thu Dec  1 07:18:07 2011
@@ -27,8 +27,8 @@ import java.util.Set;
 
 import org.apache.struts2.json.annotations.JSON;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionSupport;
 
 /**
  */

Modified: struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsJUnit4TestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsJUnit4TestCase.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsJUnit4TestCase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsJUnit4TestCase.java Thu Dec  1 07:18:07 2011
@@ -21,12 +21,12 @@
 
 package org.apache.struts2;
 
-import com.opensymphony.xwork2.*;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.interceptor.annotations.After;
-import com.opensymphony.xwork2.interceptor.annotations.Before;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.logging.jdk.JdkLoggerFactory;
+import org.apache.struts2.xwork2.*;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.interceptor.annotations.After;
+import org.apache.struts2.xwork2.interceptor.annotations.Before;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.jdk.JdkLoggerFactory;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.dispatcher.Dispatcher;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsTestCase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsTestCase.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsTestCase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/junit/src/main/java/org/apache/struts2/StrutsTestCase.java Thu Dec  1 07:18:07 2011
@@ -21,13 +21,13 @@
 
 package org.apache.struts2;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.XWorkTestCase;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.logging.jdk.JdkLoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.XWorkTestCase;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.jdk.JdkLoggerFactory;
 import org.apache.struts2.dispatcher.Dispatcher;
 import org.apache.struts2.dispatcher.mapper.ActionMapper;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/JUnitTestAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/JUnitTestAction.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/JUnitTestAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/JUnitTestAction.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 public class JUnitTestAction extends ActionSupport {
     private String name;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsSpringJUnit4TestCaseTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsSpringJUnit4TestCaseTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsSpringJUnit4TestCaseTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsSpringJUnit4TestCaseTest.java Thu Dec  1 07:18:07 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionProxy;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;
 import org.junit.Assert;
 import org.junit.Test;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsTestCaseTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsTestCaseTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsTestCaseTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/junit/src/test/java/org/apache/struts2/StrutsTestCaseTest.java Thu Dec  1 07:18:07 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionProxy;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;
 
 import javax.servlet.ServletException;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/BundlePackageLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/BundlePackageLoader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/BundlePackageLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/BundlePackageLoader.java Thu Dec  1 07:18:07 2011
@@ -28,18 +28,14 @@ import java.util.*;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.PackageProvider;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.impl.DefaultConfiguration;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
-import com.opensymphony.xwork2.util.location.Location;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.impl.DefaultConfiguration;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Package loader implementation that loads resources from a bundle

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DefaultBundleAccessor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DefaultBundleAccessor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DefaultBundleAccessor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DefaultBundleAccessor.java Thu Dec  1 07:18:07 2011
@@ -24,22 +24,19 @@ package org.apache.struts2.osgi;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
-import java.net.MalformedURLException;
 import java.util.*;
-import java.util.Map.Entry;
 
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.InvalidSyntaxException;
 import org.osgi.framework.ServiceReference;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
 
 /**
  * Helper class that find resources and loads classes from the list of bundles

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DelegatingObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DelegatingObjectFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DelegatingObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/DelegatingObjectFactory.java Thu Dec  1 07:18:07 2011
@@ -23,10 +23,10 @@ package org.apache.struts2.osgi;
 
 import java.util.Map;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.PackageProvider;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.PackageProvider;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.struts2.util.ObjectFactoryDestroyable;
 
 public class DelegatingObjectFactory extends ObjectFactory implements ObjectFactoryDestroyable {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/FelixOsgiHost.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/FelixOsgiHost.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/FelixOsgiHost.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/FelixOsgiHost.java Thu Dec  1 07:18:07 2011
@@ -21,27 +21,22 @@
 
 package org.apache.struts2.osgi;
 
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.URLUtil;
-import com.opensymphony.xwork2.util.finder.ResourceFinder;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.util.URLUtil;
+import org.apache.struts2.xwork2.util.finder.ResourceFinder;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringUtils;
 import org.apache.felix.framework.Felix;
 import org.apache.felix.framework.util.FelixConstants;
 import org.apache.felix.main.AutoActivator;
 import org.apache.felix.main.Main;
 import org.apache.felix.shell.ShellService;
-import org.apache.struts2.StrutsStatics;
 import org.apache.struts2.StrutsException;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.Constants;
 import org.osgi.framework.BundleContext;
-import org.osgi.framework.BundleListener;
-import org.osgi.framework.BundleEvent;
 import org.osgi.util.tracker.ServiceTracker;
 
 import javax.servlet.ServletContext;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiConfigurationProvider.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiConfigurationProvider.java Thu Dec  1 07:18:07 2011
@@ -21,16 +21,16 @@
 
 package org.apache.struts2.osgi;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.PackageProvider;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.PackageProvider;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.osgi.loaders.VelocityBundleResourceLoader;
 import org.apache.struts2.views.velocity.VelocityManager;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/OsgiUtil.java Thu Dec  1 07:18:07 2011
@@ -21,17 +21,13 @@
 
 package org.apache.struts2.osgi;
 
-import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.net.URL;
 import java.net.MalformedURLException;
 
-import org.osgi.framework.BundleContext;
-import org.osgi.framework.InvalidSyntaxException;
-import org.osgi.framework.ServiceReference;
 import org.osgi.framework.Bundle;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 public class OsgiUtil {
     private static final Logger LOG = LoggerFactory.getLogger(OsgiUtil.class);

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/PackageLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/PackageLoader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/PackageLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/PackageLoader.java Thu Dec  1 07:18:07 2011
@@ -27,10 +27,9 @@ import java.util.Map;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.PackageProvider;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
 
 /**
  * Implementations of this interface can load packages from a Bundle

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/SpringOsgiObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/SpringOsgiObjectFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/SpringOsgiObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/SpringOsgiObjectFactory.java Thu Dec  1 07:18:07 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.osgi;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.osgi.framework.ServiceReference;
 
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/interceptor/OsgiInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/interceptor/OsgiInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/interceptor/OsgiInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/interceptor/OsgiInterceptor.java Thu Dec  1 07:18:07 2011
@@ -20,11 +20,11 @@
  */
 package org.apache.struts2.osgi.interceptor;
 
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
 
 import javax.servlet.ServletContext;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/loaders/StaticContentBundleResourceLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/loaders/StaticContentBundleResourceLoader.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/loaders/StaticContentBundleResourceLoader.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/java/org/apache/struts2/osgi/loaders/StaticContentBundleResourceLoader.java Thu Dec  1 07:18:07 2011
@@ -22,13 +22,11 @@
 package org.apache.struts2.osgi.loaders;
 
 import java.io.IOException;
-import java.io.InputStream;
 import java.net.URL;
 
 import org.apache.struts2.dispatcher.DefaultStaticContentLoader;
-import org.apache.struts2.osgi.DefaultBundleAccessor;
 import org.apache.struts2.osgi.BundleAccessor;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.inject.Inject;
 
 /**
  * Loads static resources from bundles 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/resources/struts-plugin.xml
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/resources/struts-plugin.xml?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/resources/struts-plugin.xml (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/main/resources/struts-plugin.xml Thu Dec  1 07:18:07 2011
@@ -15,10 +15,10 @@
     <bean type="org.apache.struts2.osgi.BundleAccessor" class="org.apache.struts2.osgi.DefaultBundleAccessor" />
     <bean type="org.apache.struts2.osgi.PackageLoader" class="org.apache.struts2.osgi.BundlePackageLoader" />
     
-    <bean name="osgi" type="com.opensymphony.xwork2.ObjectFactory" class="org.apache.struts2.osgi.DelegatingObjectFactory" />
-    <bean name="springOsgi" type="com.opensymphony.xwork2.ObjectFactory" class="org.apache.struts2.osgi.SpringOsgiObjectFactory" />
-    <bean name="osgi" type="com.opensymphony.xwork2.config.PackageProvider" class="org.apache.struts2.osgi.OsgiConfigurationProvider" />
-    <bean name="osgi" type="com.opensymphony.xwork2.util.finder.ClassLoaderInterface" class="org.apache.struts2.osgi.BundleClassLoaderInterface" />
+    <bean name="osgi" type="org.apache.struts2.xwork2.ObjectFactory" class="org.apache.struts2.osgi.DelegatingObjectFactory" />
+    <bean name="springOsgi" type="org.apache.struts2.xwork2.ObjectFactory" class="org.apache.struts2.osgi.SpringOsgiObjectFactory" />
+    <bean name="osgi" type="org.apache.struts2.xwork2.config.PackageProvider" class="org.apache.struts2.osgi.OsgiConfigurationProvider" />
+    <bean name="osgi" type="org.apache.struts2.xwork2.util.finder.ClassLoaderInterface" class="org.apache.struts2.osgi.BundleClassLoaderInterface" />
 
     <package name="osgi-default" extends="struts-default" abstract="yes">
         <interceptors>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/test/java/org/apache/struts2/osgi/interceptor/OsgiInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/test/java/org/apache/struts2/osgi/interceptor/OsgiInterceptorTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/test/java/org/apache/struts2/osgi/interceptor/OsgiInterceptorTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/osgi/src/test/java/org/apache/struts2/osgi/interceptor/OsgiInterceptorTest.java Thu Dec  1 07:18:07 2011
@@ -7,7 +7,7 @@ import org.osgi.framework.ServiceReferen
 
 import javax.servlet.ServletContext;
 
-import com.opensymphony.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionInvocation;
 import junit.framework.TestCase;
 
 import java.util.List;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/DefaultOValValidationManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/DefaultOValValidationManager.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/DefaultOValValidationManager.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/DefaultOValValidationManager.java Thu Dec  1 07:18:07 2011
@@ -1,9 +1,8 @@
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.FileManager;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.FileManager;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import net.sf.oval.configuration.Configurer;
 import net.sf.oval.configuration.annotation.AnnotationsConfigurer;
 import net.sf.oval.configuration.annotation.JPAAnnotationsConfigurer;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/OValValidationInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/OValValidationInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/FieldsWithProfiles.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/FieldsWithProfiles.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 import net.sf.oval.constraint.NotNull;
 import org.apache.struts2.oval.annotation.Profiles;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/MemberObject.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/MemberObject.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/MemberObject.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/MemberObject.java Thu Dec  1 07:18:07 2011
@@ -4,7 +4,7 @@ import net.sf.oval.constraint.AssertVali
 
 import org.apache.struts2.oval.interceptor.domain.Person;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 public class MemberObject extends ActionSupport {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ModelDrivenAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ModelDrivenAction.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ModelDrivenAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ModelDrivenAction.java Thu Dec  1 07:18:07 2011
@@ -4,8 +4,8 @@ import net.sf.oval.constraint.AssertVali
 
 import org.apache.struts2.oval.interceptor.domain.Person;
 
-import com.opensymphony.xwork2.ActionSupport;
-import com.opensymphony.xwork2.ModelDriven;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ModelDriven;
 
 public class ModelDrivenAction extends ActionSupport implements ModelDriven<Person> {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/OValValidationInterceptorTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/OValValidationInterceptorTest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/OValValidationInterceptorTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/OValValidationInterceptorTest.java Thu Dec  1 07:18:07 2011
@@ -20,10 +20,10 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.XWorkTestCase;
-import com.opensymphony.xwork2.config.providers.XmlConfigurationProvider;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.XWorkTestCase;
+import org.apache.struts2.xwork2.config.providers.XmlConfigurationProvider;
 
 import java.util.Arrays;
 import java.util.List;
@@ -31,7 +31,6 @@ import java.util.Map;
 import java.util.Locale;
 
 import net.sf.oval.configuration.Configurer;
-import org.apache.struts2.oval.interceptor.OValValidationManager;
 
 public class OValValidationInterceptorTest extends XWorkTestCase {
     public void testSimpleFieldsXML() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleField.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleField.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleField.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleField.java Thu Dec  1 07:18:07 2011
@@ -23,7 +23,7 @@ package org.apache.struts2.oval.intercep
 import net.sf.oval.constraint.Length;
 import net.sf.oval.constraint.NotEmpty;
 import net.sf.oval.constraint.NotNull;
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 public class SimpleField extends ActionSupport{
     @NotNull()

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18n.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18n.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18n.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18n.java Thu Dec  1 07:18:07 2011
@@ -20,10 +20,8 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 import net.sf.oval.constraint.NotNull;
-import net.sf.oval.constraint.NotEmpty;
-import net.sf.oval.constraint.Length;
 
 public class SimpleFieldI18n  extends ActionSupport {
     @NotNull(message = "notnull.field")

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18nDefaultKey.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18nDefaultKey.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18nDefaultKey.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldI18nDefaultKey.java Thu Dec  1 07:18:07 2011
@@ -20,10 +20,8 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 import net.sf.oval.constraint.NotNull;
-import net.sf.oval.constraint.NotEmpty;
-import net.sf.oval.constraint.Length;
 
 public class SimpleFieldI18nDefaultKey extends ActionSupport {
     @NotNull(message = "notnull.field")

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldJPAAnnotations.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldJPAAnnotations.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldJPAAnnotations.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldJPAAnnotations.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 import javax.persistence.Basic;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldOGNLExpression.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldOGNLExpression.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldOGNLExpression.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldOGNLExpression.java Thu Dec  1 07:18:07 2011
@@ -20,11 +20,8 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import net.sf.oval.constraint.NotNull;
-import net.sf.oval.constraint.NotEmpty;
-import net.sf.oval.constraint.Length;
 import net.sf.oval.constraint.Assert;
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 public class SimpleFieldOGNLExpression extends ActionSupport {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldsXML.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldsXML.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldsXML.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleFieldsXML.java Thu Dec  1 07:18:07 2011
@@ -1,7 +1,6 @@
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
-import net.sf.oval.constraint.NotEmpty;
+import org.apache.struts2.xwork2.ActionSupport;
 import net.sf.oval.constraint.NotNull;
 
 public class SimpleFieldsXML extends ActionSupport {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleMethod.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleMethod.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleMethod.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/SimpleMethod.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 import net.sf.oval.constraint.Length;
 import net.sf.oval.constraint.NotNull;
 import net.sf.oval.configuration.annotation.IsInvariant;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ValidationInMethods.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ValidationInMethods.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ValidationInMethods.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/ValidationInMethods.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 import net.sf.oval.constraint.NotNull;
 import net.sf.oval.configuration.annotation.IsInvariant;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/VoidResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/VoidResult.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/VoidResult.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/VoidResult.java Thu Dec  1 07:18:07 2011
@@ -20,8 +20,8 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.ActionInvocation;
 
 public class VoidResult implements Result {
     public void execute(ActionInvocation invocation) throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/pell-multipart/src/main/java/org/apache/struts2/dispatcher/multipart/PellMultiPartRequest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/pell-multipart/src/main/java/org/apache/struts2/dispatcher/multipart/PellMultiPartRequest.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/pell-multipart/src/main/java/org/apache/struts2/dispatcher/multipart/PellMultiPartRequest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/pell-multipart/src/main/java/org/apache/struts2/dispatcher/multipart/PellMultiPartRequest.java Thu Dec  1 07:18:07 2011
@@ -35,9 +35,9 @@ import javax.servlet.http.HttpServletReq
 
 import org.apache.struts2.StrutsConstants;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusFilter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusFilter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusFilter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusFilter.java Thu Dec  1 07:18:07 2011
@@ -36,8 +36,8 @@ import javax.servlet.http.HttpSession;
 
 import org.codehaus.plexus.PlexusContainer;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Creates a plexus container for the application, session, and request

Modified: struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusLifecycleListener.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusLifecycleListener.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusLifecycleListener.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusLifecycleListener.java Thu Dec  1 07:18:07 2011
@@ -33,8 +33,8 @@ import javax.servlet.http.HttpSessionLis
 import org.codehaus.plexus.DefaultPlexusContainer;
 import org.codehaus.plexus.PlexusContainer;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Manages the Plexus lifecycle for the servlet and session contexts

Modified: struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusObjectFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusObjectFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusObjectFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusObjectFactory.java Thu Dec  1 07:18:07 2011
@@ -28,18 +28,18 @@ import javax.servlet.ServletContext;
 
 import org.codehaus.plexus.PlexusContainer;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.InterceptorConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.Interceptor;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.validator.Validator;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.InterceptorConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.Interceptor;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.validator.Validator;
 
 /**
  * Plexus integartion. You need three optional files: plexus-request.xml, plexus-session.xml, and

Modified: struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusUtils.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusUtils.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusUtils.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/java/org/apache/struts2/plexus/PlexusUtils.java Thu Dec  1 07:18:07 2011
@@ -28,8 +28,8 @@ import java.io.InputStreamReader;
 import org.codehaus.plexus.PlexusContainer;
 import org.codehaus.plexus.configuration.PlexusConfigurationResourceException;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Utility methods for dealing with Plexus

Modified: struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/resources/struts-plugin.xml
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/resources/struts-plugin.xml?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/resources/struts-plugin.xml (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/plexus/src/main/resources/struts-plugin.xml Thu Dec  1 07:18:07 2011
@@ -26,7 +26,7 @@
     "http://struts.apache.org/dtds/struts-2.0.dtd">
     
 <struts>
-    <bean type="com.opensymphony.xwork2.ObjectFactory" name="plexus" class="org.apache.struts2.plexus.PlexusObjectFactory" />
+    <bean type="org.apache.struts2.xwork2.ObjectFactory" name="plexus" class="org.apache.struts2.plexus.PlexusObjectFactory" />
     
     <!--  Make the Plexus object factory the automatic default -->
     <constant name="struts.objectFactory" value="plexus" />

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/components/PortletUrlRenderer.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/components/PortletUrlRenderer.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/components/PortletUrlRenderer.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/components/PortletUrlRenderer.java Thu Dec  1 07:18:07 2011
@@ -30,11 +30,11 @@ import org.apache.struts2.portlet.contex
 import org.apache.struts2.portlet.util.PortletUrlHelper;
 import org.apache.struts2.portlet.util.PortletUrlHelperJSR286;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * Implementation of the {@link UrlRenderer} interface that renders URLs for portlet environments.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletRequestMap.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletRequestMap.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletRequestMap.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletRequestMap.java Thu Dec  1 07:18:07 2011
@@ -27,8 +27,8 @@ import java.util.Set;
 
 import javax.portlet.PortletRequest;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * A simple implementation of the {@link java.util.Map} interface to handle a collection of request attributes.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletSessionMap.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletSessionMap.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletSessionMap.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/PortletSessionMap.java Thu Dec  1 07:18:07 2011
@@ -29,8 +29,8 @@ import java.util.Set;
 import javax.portlet.PortletRequest;
 import javax.portlet.PortletSession;
 
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * A simple implementation of the {@link java.util.Map} interface to handle a collection of portlet session

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/context/PortletActionContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/context/PortletActionContext.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/context/PortletActionContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/context/PortletActionContext.java Thu Dec  1 07:18:07 2011
@@ -34,7 +34,7 @@ import javax.portlet.RenderResponse;
 import org.apache.struts2.StrutsStatics;
 import org.apache.struts2.dispatcher.mapper.ActionMapping;
 
-import com.opensymphony.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionContext;
 
 import static org.apache.struts2.portlet.PortletConstants.*;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/DirectRenderFromEventAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/DirectRenderFromEventAction.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/DirectRenderFromEventAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/DirectRenderFromEventAction.java Thu Dec  1 07:18:07 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.portlet.dispatcher;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 import java.io.Serializable;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr168Dispatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr168Dispatcher.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr168Dispatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr168Dispatcher.java Thu Dec  1 07:18:07 2011
@@ -77,15 +77,15 @@ import org.apache.struts2.portlet.servle
 import org.apache.struts2.portlet.servlet.PortletServletResponse;
 import org.apache.struts2.util.AttributeMap;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.FileManager;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.util.FileManager;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr286Dispatcher.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr286Dispatcher.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr286Dispatcher.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/portlet/src/main/java/org/apache/struts2/portlet/dispatcher/Jsr286Dispatcher.java Thu Dec  1 07:18:07 2011
@@ -1,8 +1,8 @@
 package org.apache.struts2.portlet.dispatcher;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.struts2.portlet.servlet.PortletServletResponse;
 import org.apache.struts2.portlet.servlet.PortletServletResponseJSR286;
--- struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/OValValidationInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/oval/src/main/java/org/apache/struts2/oval/interceptor/OValValidationInterceptor.java Thu Dec  1 07:18:07 2011
@@ -20,18 +20,18 @@
  */
 package org.apache.struts2.oval.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ActionProxy;
-import com.opensymphony.xwork2.ModelDriven;
-import com.opensymphony.xwork2.Validateable;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.interceptor.MethodFilterInterceptor;
-import com.opensymphony.xwork2.interceptor.PrefixMethodInvocationUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.validator.DelegatingValidatorContext;
-import com.opensymphony.xwork2.validator.ValidatorContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionProxy;
+import org.apache.struts2.xwork2.ModelDriven;
+import org.apache.struts2.xwork2.Validateable;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor;
+import org.apache.struts2.xwork2.interceptor.PrefixMethodInvocationUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.validator.DelegatingValidatorContext;
+import org.apache.struts2.xwork2.validator.ValidatorContext;
 import net.sf.oval.ConstraintViolation;
 import net.sf.oval.Validator;
 import net.sf.oval.configuration.Configurer;
@@ -72,7 +72,7 @@ public class OValValidationInterceptor e
     }
 
     /**
      * Determines if {@link com.opensymphony.xwork2.Validateable}'s <code>validate()</code> should be called,
      * as well as methods whose name that start with "validate". Defaults to "true".
      *
      * @param programmatic <tt>true</tt> then <code>validate()</code> is invoked.
@@ -82,7 +82,7 @@ public class OValValidationInterceptor e
     }
 
     /**
      * Determines if {@link com.opensymphony.xwork2.Validateable}'s <code>validate()</code> should always
      * be invoked. Default to "true".
      *
      * @param alwaysInvokeValidate <tt>true</tt> then <code>validate()</code> is always invoked.
@@ -72,7 +72,7 @@ public class OValValidationInterceptor e
 
     /**
-     * Determines if {@link com.opensymphony.xwork2.Validateable}'s <code>validate()</code> should be called,
+     * Determines if {@link org.apache.struts2.xwork2.Validateable}'s <code>validate()</code> should be called,
      * as well as methods whose name that start with "validate". Defaults to "true".
      *
@@ -82,7 +82,7 @@ public class OValValidationInterceptor e
 
     /**
-     * Determines if {@link com.opensymphony.xwork2.Validateable}'s <code>validate()</code> should always
+     * Determines if {@link org.apache.struts2.xwork2.Validateable}'s <code>validate()</code> should always
      * be invoked. Default to "true".
      *

Modified: struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/FieldsWithProfiles.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/oval/src/test/java/org/apache/struts2/oval/interceptor/FieldsWithProfiles.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================